import unittest
import numpy as np
import random
import time
from cryolo.augmentation import Augmentation

class AugTest(unittest.TestCase):

    def test_image_augmentation_time(self):
        np.random.seed(6)
        random.seed(10)
        img = np.random.random_sample(size=(4096, 4096))*255
        img = img.astype(np.uint8)
        img = img.astype(np.float32)
        start = time.time()
        aug = Augmentation(True)
        for i in range(10):
            aug.image_augmentation(img.copy())
            #aug.gauss_blur(img.copy())
            #print img.dtype
        end = time.time()

    def test_sharpen_float32(self):
        np.random.seed(6)
        random.seed(10)
        img = np.random.random_sample(size=(100, 100))*255
        img = img.astype(np.uint8)
        img = img.astype(np.float32)
        aug = Augmentation()
        result = aug.gauss_blur(img.copy())


    def test_image_augmentation_float32(self):
        np.random.seed(6)
        random.seed(10)
        img = np.random.random_sample(size=(10, 10))
        img = img.astype(np.float32)
        aug = Augmentation()
        result = aug.image_augmentation(img.copy())
        is_float = np.issubdtype(result.dtype, np.float32)
        self.assertTrue(is_float, "Image augmentation failed. Type is not correct")

    def test_image_augmentation_uint8(self):
        np.random.seed(7)
        random.seed(10)
        img = np.random.random_integers(0, 255, size=(10, 10))
        img = img.astype(np.float32)
        aug = Augmentation(True)
        result = aug.image_augmentation(img.copy())
        is_int = np.issubdtype(result.dtype, np.uint8)
        self.assertTrue(is_int, "Image augmentation failed. Type is not correct")


    def test_additive_gauss_noise_typecheck_float32(self):
        img = np.random.random_sample(size=(3, 3))
        img = img.astype(np.float32)
        aug = Augmentation()
        result = aug.additive_gauss_noise(img.copy())
        is_float = np.issubdtype(result.dtype, np.float32)
        self.assertTrue(is_float, "ADD GAUSS NOISE FLOAT32 failed. Type is not correct")


    def test_avg_blur_float32(self):
        np.random.seed(7)
        img = np.random.random_sample(size=(3,3))
        img = img.astype(np.float32)
        aug = Augmentation()
        result = aug.avg_blur(img.copy(), kernel_size=(3,4))
        t = np.allclose(np.mean(img), result[1, 1], atol=0.0001)
        self.assertTrue(t, "AVG BLUR FLOAT32 failed.")
        is_float = np.issubdtype(result.dtype, np.float32)
        self.assertTrue(is_float, "AVG BLUR FLOAT32 failed. Type is not correct")


    def test_avg_blur_uint8(self):
        np.random.seed(7)
        img = np.random.random_integers(0,255,size=(3,3))
        print(img)
        img = img.astype(np.uint8)
        aug = Augmentation(True)
        result = aug.avg_blur(img.copy(), kernel_size=(3,4))
        self.assertEqual(140, result[1, 1])
        is_int = np.issubdtype(result.dtype, np.uint8)
        self.assertTrue(is_int, "Avg blurring failed. Type is not correct")


    def test_gaussian_blur_float32(self):
        np.random.seed(7)
        img = np.random.random_sample(size=(3,3))
        aug = Augmentation()
        result = aug.gauss_blur(img.copy())
        print(result)
        img_exp = [[0.3956204, 0.45140969, 0.4693832],
                   [0.43998803, 0.44855732, 0.43916815],
                   [0.43967383, 0.40600407, 0.37695657]]
        t = np.allclose(img_exp, result, atol=0.00001)
        self.assertTrue(t, "Gaussian blurring failed")
        is_float = np.issubdtype(result.dtype, np.float32)

        self.assertTrue(is_float, "Gaussian blurring failed. Type is not correct")

    def test_gaussian_blur_uint8(self):
        np.random.seed(7)
        img = np.random.random_integers(0,255,size=(3,3))
        img = img.astype(np.float32)
        aug = Augmentation(True)
        result = aug.gauss_blur(img.copy())
        result = result.astype(np.uint8)
        print(result)
        img_exp = [[178, 144,  99], [175, 140, 125], [154, 125, 115]]
        t = np.array_equal(img_exp, result)
        self.assertTrue(t,"Gaussian blurring failed")

        is_int = np.issubdtype(result.dtype, np.integer)

        self.assertTrue(is_int, "Gaussian blurring failed. Type is not correct")

    def test_contrast_normalization_float32(self):
        np.random.seed(9)
        img = np.zeros((3, 3), dtype="float32")
        img[2, 2] = 255
        aug = Augmentation()
        print(img)
        result = aug.contrast_normalization(img.copy())
        print(result)

        img_exp = np.array([[0, 0, 0], [0, 0, 0], [0, 0, 131.46811]])

        t = np.allclose(img_exp, result,atol=0.0001)
        self.assertTrue(t, msg="Contrast normalization failed. Result is not as expected")

        is_float = np.issubdtype(result.dtype, np.float32)

        self.assertTrue(is_float, "Contrast normalization failed. Type is not correct")

    def test_contrast_normalization_uint8(self):
        np.random.seed(9)
        img = np.zeros((3, 3), dtype="float32")
        img[2, 2] = 255
        aug = Augmentation(True)
        result = aug.contrast_normalization(img.copy())
        print(result)
        result = result.astype(np.uint8)
        img_exp = np.array([[0, 0, 0], [0, 0, 0], [0, 0, 131]])

        t = np.allclose(img_exp, result,atol=0.0001)

        self.assertTrue(t, msg="Contrast normalization failed. Result is not as expected")


    def test_add_float32(self):
        np.random.seed(10)
        img = np.ones((3, 3), dtype="float32")
        img[0, 0] = 0
        img[2, 2] = 10
        aug = Augmentation()
        result = aug.add(img.copy(), 0.1)
        print(result)
        t = np.array_equal(img+0.46959287, result)
        self.assertTrue(t, msg="Add failed. Result is not as expected")

        is_float = np.issubdtype(result.dtype, np.float32)

        self.assertTrue(is_float, "Add failed. Type is not correct")

    def test_add_uint8(self):
        np.random.seed(10)
        img = np.zeros((3, 3), dtype="float32")
        img[2, 2] = 255

        aug = Augmentation(True)
        result = aug.add(img.copy(), 0.1)
        result = np.clip(result,0,255)
        print(result)
        img_exp = img+13.045981748296022
        img_exp[2,2] = 255.
        t = np.array_equal(img_exp, result)

        self.assertTrue(t, msg="Add failed. Result is not as expected")

    def test_multiply_float32(self):
        np.random.seed(10)
        img = np.ones((3, 3), dtype="float32")
        aug = Augmentation()
        result = aug.multiply(img.copy())
        img_exp = img*1.27132064327
        t = np.array_equal(img_exp, result)
        self.assertTrue(t, msg="Float 32 multiplication failed. Result is not as expected")

        is_float = np.issubdtype(result.dtype, np.float32)

        self.assertTrue(is_float, "Multiplication failed. Type is not correct")

    def test_multiply_uint8(self):
        np.random.seed(10)
        img = np.ones((3, 3), dtype="float32")
        img = img * 100
        img[2,2] = 250
        aug = Augmentation(True)
        result = aug.multiply(img.copy())
        np.clip(result,0,255,out=result)
        result = result.astype(np.uint8, copy=False)

        img_exp = [[127, 127, 127],
                   [127, 127, 127],
                   [127, 127, 255]]

        t = np.array_equal(img_exp, result)
        self.assertTrue(t, msg="unit8 multiplication failed. Result is not as expected")

        is_int = np.issubdtype(result.dtype, np.uint8)

        self.assertTrue(is_int, "Multiplication failed. Type is not correct")

    def test_dropout_5x5_float32(self):
        np.random.seed(10)
        img = np.ones((6, 6), dtype="float32")
        img[:3,:] = 3
        aug = Augmentation()
        res = aug.dropout(img.copy(), 0.1)
        num_zero_elements = np.sum(res == 2)
        self.assertEqual(3, num_zero_elements,"Dropout test failed.")

        is_float = np.issubdtype(res.dtype, np.float32)

        self.assertTrue(is_float, "Dropout failed. Type is not correct")

    def test_dropout_5x5_uint8(self):
        np.random.seed(10)
        img = np.ones((6, 6), dtype="float32")
        img[:3, :] = 3
        aug = Augmentation(True)
        res = aug.dropout(img.copy(), 0.1)
        num_zero_elements = np.sum(res == 2)
        self.assertEqual(3, num_zero_elements, "Dropout test failed.")

    def test_dropout_10x10_uint8(self):
        np.random.seed(10)
        img = np.ones((10, 10), dtype="float32")
        img[:5, :] = 3
        aug = Augmentation(True)
        res = aug.dropout(img.copy(), 0.1)
        num_zero_elements = np.sum(res == 2)
        self.assertEqual(8, num_zero_elements, "Dropout test failed.")


import unittest

import cryolo.utils

class MyTestCase(unittest.TestCase):
    def test_resample_filament_returns_fila(self):

        boxes = []
        boxes.append(cryolo.utils.BoundBox(x=1182, y=2116, w=30, h=30, c = 1, classes=""))
        boxes.append(cryolo.utils.BoundBox(x=1248, y=1926, w=30, h=30, c = 1, classes=""))
        fil = cryolo.utils.Filament(boxes)
        res_fil = cryolo.utils.resample_filament(fil, 10)
        self.assertTrue(res_fil.boxes is not None,"No boxes")

    def test_resample_filament_correct_length(self):

        boxes = []
        boxes.append(cryolo.utils.BoundBox(x=0, y=0, w=30, h=30, c = 1, classes=""))
        boxes.append(cryolo.utils.BoundBox(x=100, y=0, w=30, h=30, c = 1, classes=""))
        fil = cryolo.utils.Filament(boxes)
        res_fil = cryolo.utils.resample_filament(fil, 10)
        self.assertEqual(10,len(res_fil.boxes))

    def test_resample_filament_correct_maxx(self):

        boxes = []
        boxes.append(cryolo.utils.BoundBox(x=20, y=5, w=30, h=30, c = 1, classes=""))
        boxes.append(cryolo.utils.BoundBox(x=85, y=35, w=30, h=30, c = 1, classes=""))
        fil = cryolo.utils.Filament(boxes)
        res_fil = cryolo.utils.resample_filament(fil, 6)
        for b in res_fil.boxes:
            print(b.x,b.y)
        self.assertTrue(res_fil.boxes[-1].x <= 85)
        self.assertTrue(res_fil.boxes[0].x >= 20)
        self.assertTrue(res_fil.boxes[-1].y <= 35)
        self.assertTrue(res_fil.boxes[0].y >= 5)


if __name__ == '__main__':
    unittest.main()



import unittest
from cryolo import eval
import os
class MyTestCase(unittest.TestCase):

    def test_readbox(self):
        path = os.path.join(os.path.dirname(__file__), "../resources/2018_08_14_BBSXL_AuXPos1_02791.box")
        boxes = eval.read_box(path, 0)

        self.assertEqual(len(boxes),1)


if __name__ == '__main__':
    unittest.main()



import unittest
from cryolo.lowpass import zero_pad, next_power_of2
import numpy as np
class MyTestCase(unittest.TestCase):

    def test_zeropad_correct_size(self):

        img = np.zeros((5,5)) + 1
        new_size = (10,10)
        padded, _ = zero_pad(img, new_size)
        self.assertTupleEqual(padded.shape,new_size)

    def test_next_power_of2(self):

        num = next_power_of2(2**2 +1)
        self.assertEqual(num, 2**3)


if __name__ == '__main__':
    unittest.main()



import unittest
import os
import pickle
from cryolo.frontend import YOLO
import cryolo.utils as utils
class FrontendTest(unittest.TestCase):


    def test_nms_no_overlapping_boxes(self):
        box = utils.BoundBox(x=10, y=10, w=10, h=10,c=0,classes=[1])
        box2 = utils.BoundBox(x=20, y=20, w=10, h=10,c=0,classes=[1])

        boxes = [box,box2]
        front = YOLO("YOLO", [768, 768], 3, ["p"], 700, [200, 200], backend_weights=None, uniitest=True)
        front.nms_threshold = 0.3
        front.obj_threshold = 0.3
        res = front.non_maxima_suppress_fast(boxes)

        self.assertEqual(len(res), 2)

    def test_nms_two_overlapping(self):
        box = utils.BoundBox(x=10, y=10, w=10, h=10, c=0, classes=[1])
        box2 = utils.BoundBox(x=12, y=12, w=10, h=10, c=0, classes=[1])
        box3 = utils.BoundBox(x=20, y=20, w=10, h=10, c=0, classes=[1])
        box4 = utils.BoundBox(x=22, y=22, w=10, h=10, c=0, classes=[1])

        boxes = [box, box2,box3,box4]
        front = YOLO("YOLO", [768, 768], 3, ["p"], 700, [200, 200], backend_weights=None, uniitest=True)
        front.nms_threshold = 0.3
        front.obj_threshold = 0.3
        res = front.non_maxima_suppress_fast(boxes)

        self.assertEqual(len(res), 2)

if __name__ == '__main__':
    unittest.main()
